//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
// 
// scan.h -- 
// 
// Author           : Richard A. Stroobosscher
// Created On       : Tue Apr 28 15:43:34 1992
// Last Modified By : Peter A. Buhr
// Last Modified On : Sat Feb 10 10:54:49 2007
// Update Count     : 11
//
// This  library is free  software; you  can redistribute  it and/or  modify it
// under the terms of the GNU Lesser General Public License as published by the
// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
// option) any later version.
// 
// This library is distributed in the  hope that it will be useful, but WITHOUT
// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
// for more details.
// 
// You should  have received a  copy of the  GNU Lesser General  Public License
// along  with this library.
// 

#ifndef __SCAN_H__
#define __SCAN_H__

void scan();
void unscan( token_t *back );

#endif // __SCAN_H__

// Local Variables: //
// compile-command: "gmake install" //
// End: //
